==> apo-ws-client-6.00.10.2-sources.jar: fr/univlorraine/apowsclient/pjOpi/RecupererPiecesJustificativesOPIWS.java <==

package fr.univlorraine.apowsclient.pjOpi;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="_codOpiIntEpo" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_libNomPatIndOpi" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_libPr1IndOpi" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_codTpj" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_nomFic" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_pj" type="{http://www.w3.org/2001/XMLSchema}base64Binary"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "codOpiIntEpo",
    "libNomPatIndOpi",
    "libPr1IndOpi",
    "codTpj",
    "nomFic",
    "pj"
})
@XmlRootElement(name = "recupererPiecesJustificativesOPIWS", namespace = "gouv.education.apogee.commun.servicesmetiers.PjOpiMetier_16012017")
public class RecupererPiecesJustificativesOPIWS {

    @XmlElement(name = "_codOpiIntEpo", required = true)
    protected String codOpiIntEpo;
    @XmlElement(name = "_libNomPatIndOpi", required = true)
    protected String libNomPatIndOpi;
    @XmlElement(name = "_libPr1IndOpi", required = true)
    protected String libPr1IndOpi;
    @XmlElement(name = "_codTpj", required = true)
    protected String codTpj;
    @XmlElement(name = "_nomFic", required = true)
    protected String nomFic;
    @XmlElement(name = "_pj", required = true)
    protected byte[] pj;

    /**
     * Obtient la valeur de la propriété codOpiIntEpo.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodOpiIntEpo() {
        return codOpiIntEpo;
    }

    /**
     * Définit la valeur de la propriété codOpiIntEpo.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodOpiIntEpo(String value) {
        this.codOpiIntEpo = value;
    }

    /**
     * Obtient la valeur de la propriété libNomPatIndOpi.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibNomPatIndOpi() {
        return libNomPatIndOpi;
    }

    /**
     * Définit la valeur de la propriété libNomPatIndOpi.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibNomPatIndOpi(String value) {
        this.libNomPatIndOpi = value;
    }

    /**
     * Obtient la valeur de la propriété libPr1IndOpi.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibPr1IndOpi() {
        return libPr1IndOpi;
    }

    /**
     * Définit la valeur de la propriété libPr1IndOpi.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibPr1IndOpi(String value) {
        this.libPr1IndOpi = value;
    }

    /**
     * Obtient la valeur de la propriété codTpj.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodTpj() {
        return codTpj;
    }

    /**
     * Définit la valeur de la propriété codTpj.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodTpj(String value) {
        this.codTpj = value;
    }

    /**
     * Obtient la valeur de la propriété nomFic.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNomFic() {
        return nomFic;
    }

    /**
     * Définit la valeur de la propriété nomFic.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNomFic(String value) {
        this.nomFic = value;
    }

    /**
     * Obtient la valeur de la propriété pj.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getPj() {
        return pj;
    }

    /**
     * Définit la valeur de la propriété pj.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setPj(byte[] value) {
        this.pj = value;
    }

}

==> apo-ws-client-6.00.50.2-sources.jar: fr/univlorraine/apowsclient/pjOpi/RecupererPiecesJustificativesOPIWS.java <==

package fr.univlorraine.apowsclient.pjOpi;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="_codOpiIntEpo" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_libNomPatIndOpi" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_libPr1IndOpi" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_codTpj" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_nomFic" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_pj" type="{http://www.w3.org/2001/XMLSchema}base64Binary"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "codOpiIntEpo",
    "libNomPatIndOpi",
    "libPr1IndOpi",
    "codTpj",
    "nomFic",
    "pj"
})
@XmlRootElement(name = "recupererPiecesJustificativesOPIWS", namespace = "gouv.education.apogee.commun.servicesmetiers.PjOpiMetier")
public class RecupererPiecesJustificativesOPIWS {

    @XmlElement(name = "_codOpiIntEpo", required = true)
    protected String codOpiIntEpo;
    @XmlElement(name = "_libNomPatIndOpi", required = true)
    protected String libNomPatIndOpi;
    @XmlElement(name = "_libPr1IndOpi", required = true)
    protected String libPr1IndOpi;
    @XmlElement(name = "_codTpj", required = true)
    protected String codTpj;
    @XmlElement(name = "_nomFic", required = true)
    protected String nomFic;
    @XmlElement(name = "_pj", required = true)
    protected byte[] pj;

    /**
     * Obtient la valeur de la propriété codOpiIntEpo.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodOpiIntEpo() {
        return codOpiIntEpo;
    }

    /**
     * Définit la valeur de la propriété codOpiIntEpo.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodOpiIntEpo(String value) {
        this.codOpiIntEpo = value;
    }

    /**
     * Obtient la valeur de la propriété libNomPatIndOpi.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibNomPatIndOpi() {
        return libNomPatIndOpi;
    }

    /**
     * Définit la valeur de la propriété libNomPatIndOpi.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibNomPatIndOpi(String value) {
        this.libNomPatIndOpi = value;
    }

    /**
     * Obtient la valeur de la propriété libPr1IndOpi.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibPr1IndOpi() {
        return libPr1IndOpi;
    }

    /**
     * Définit la valeur de la propriété libPr1IndOpi.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibPr1IndOpi(String value) {
        this.libPr1IndOpi = value;
    }

    /**
     * Obtient la valeur de la propriété codTpj.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodTpj() {
        return codTpj;
    }

    /**
     * Définit la valeur de la propriété codTpj.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodTpj(String value) {
        this.codTpj = value;
    }

    /**
     * Obtient la valeur de la propriété nomFic.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNomFic() {
        return nomFic;
    }

    /**
     * Définit la valeur de la propriété nomFic.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNomFic(String value) {
        this.nomFic = value;
    }

    /**
     * Obtient la valeur de la propriété pj.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getPj() {
        return pj;
    }

    /**
     * Définit la valeur de la propriété pj.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setPj(byte[] value) {
        this.pj = value;
    }

}
